==> lib_ad-2.2.6-sources.jar: com/transsion/ad/bidding/video/BiddingBuyOutBuyOutVideoActivity.kt <==
package com.transsion.ad.bidding.video

import android.annotation.SuppressLint
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import android.widget.FrameLayout
import com.bumptech.glide.Glide
import com.gyf.immersionbar.ImmersionBar
import com.transsion.ad.AdLogger
import com.transsion.ad.R
import com.transsion.ad.bidding.base.AbsBiddingActivity
import com.transsion.ad.databinding.ActivityBiddingBuyOutVideoLayoutBinding
import com.transsion.ad.monopoly.model.MbAdType
import com.transsion.ad.scene.SceneGlobalConfig
import com.transsion.ad.util.ViewUtil
import com.transsion.ad.view.AdTagView

/**
 * @author shmizhangxinbing
 * @date : 2025/6/3 14:05
 * @description: 包断激励视频广告
 */
class BiddingBuyOutBuyOutVideoActivity : AbsBiddingActivity() {

    private var isCanClickClose = false
    private var binding: ActivityBiddingBuyOutVideoLayoutBinding? = null // 页面数据


    // =============================================================================================


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        binding?.clRoot?.let {
            it.post {
                it.setPadding(
                    it.paddingLeft,
                    ImmersionBar.getStatusBarHeight(this),
                    it.paddingRight,
                    it.paddingBottom
                )
            }
        }
    }

    override fun getAdType(): Int = MbAdType.MB_AD_TYPE_VIDEO

    override fun getLogTag(): String = AdLogger.TAG_SDK_I

    override fun getSubContentView(): View? {
        binding = ActivityBiddingBuyOutVideoLayoutBinding.inflate(layoutInflater)
        return binding?.root
    }

    override fun getMediaContain(): FrameLayout? = binding?.container

    override fun getVolumeContainer(): FrameLayout? = binding?.flVolumeContainer

    override fun getCountDownTimes(): Int = SceneGlobalConfig.getVideoCd()

    override fun showAdInformation() {
        // 广告主信息 展示
        setAdvertiserInformation()
        // 广告点击事件
        ViewUtil.multipleClickListener(
            findViewById<FrameLayout>(R.id.textureView),
            findViewById<FrameLayout>(R.id.clAdEndLayout)
        ) {
            adClick()
        }

        // 关闭按钮
        binding?.ivClose?.setOnClickListener {
            if (isCanClickClose.not()) {
                // 只有在最后10秒的时候才能点击
                AdLogger.logSdkIntercept("${javaClass.simpleName} --> setOnClickListener() --> 只有在最后10秒的时候才能点击")
                return@setOnClickListener
            }
            showCloseAdDialog()
            //finishAdActivity()
        }
        binding?.ivAdClose?.setOnClickListener {
            finishAdActivity()
        }
    }

    @SuppressLint("StringFormatMatches")
    override fun refreshCountDownView(i: Int) {
        if (i <= 10) {
            isCanClickClose = true
            binding?.ivClose?.setImageResource(R.mipmap.ad_video_01)
        } else {
            binding?.ivClose?.setImageResource(R.mipmap.ad_video_03)
        }

        if (i == getCountDownTimes()) {
            binding?.tvCd?.visibility = View.VISIBLE
        }
        // 倒计时开始了
        val str = "Reward in ${i}s"
        binding?.tvCd?.text = str
        // i= 1 的时候，skip 可点击
        if (i == 0) {
            binding?.tvCd?.visibility = View.GONE
            //ivVolume?.visibility = View.GONE
            adRewarded()
        }
    }

    override fun onAdCompletion() {
        binding?.clAdEndLayout?.visibility = View.VISIBLE
    }

    override fun showCloseAdDialog() {
        if (isCanClickClose.not()) {
            // 只有在最后10秒的时候才能点击
            AdLogger.logSdkIntercept("${getClassTag()} --> showCloseAdDialog() --> 只有在最后10秒的时候才能展示")
            return
        }

        setShowCloseAdDialog(isShow = true)
        BiddingCloseAdDialog().setCallback(closeAdCallback = {
            finishAdActivity()
        }, resumeAdCallback = {
            setShowCloseAdDialog(isShow = false)
        }).showDialog(this, "CloseAdDialog")
    }

    override fun getAdIcon(): View? = findViewById<AdTagView>(R.id.adIcon)


    // ======================================== 广告展示 =============================================


    private fun setAdvertiserInformation() {
        kotlin.runCatching {
            binding?.tvAvatar?.let {
                if (TextUtils.isEmpty(getAdPlan()?.advertiserAvatarPath)) {
                    Glide.with(this).load(getAdPlan()?.advertiserAvatar).into(it)
                } else {
                    Glide.with(this).load(getAdPlan()?.advertiserAvatarPath).into(it)
                }
            }
            binding?.tvTitle?.text = getAdMaterialList()?.title
            binding?.tvDesc?.text = getAdMaterialList()?.desc
            binding?.tvBtn?.text = getAdMaterialList()?.buttonText
        }

        kotlin.runCatching {
            binding?.tvAdAvatar?.let {
                if (TextUtils.isEmpty(getAdPlan()?.advertiserAvatarPath)) {
                    Glide.with(this).load(getAdPlan()?.advertiserAvatar).into(it)
                } else {
                    Glide.with(this).load(getAdPlan()?.advertiserAvatarPath).into(it)
                }
            }

            binding?.tvAdTitle?.text = getAdMaterialList()?.title
            binding?.tvAdDesc?.text = getAdMaterialList()?.desc
            binding?.tvAdBtn?.text = getAdMaterialList()?.buttonText
        }
    }

}

==> lib_ad-2.3.1-sources.jar: com/transsion/ad/bidding/video/BiddingBuyOutBuyOutVideoActivity.kt <==
package com.transsion.ad.bidding.video

import android.annotation.SuppressLint
import android.os.Bundle
import android.text.TextUtils
import android.util.Log
import android.view.View
import android.widget.FrameLayout
import com.bumptech.glide.Glide
import com.gyf.immersionbar.ImmersionBar
import com.transsion.ad.R
import com.transsion.ad.bidding.base.AbsBiddingActivity
import com.transsion.ad.log.AdLogger
import com.transsion.ad.databinding.ActivityBiddingBuyOutVideoUnspecifiedLayoutBinding
import com.transsion.ad.monopoly.model.MbAdType
import com.transsion.ad.scene.SceneGlobalConfig
import com.transsion.ad.util.ViewUtil
import com.transsion.ad.view.AdTagView

/**
 * @author shmizhangxinbing
 * @date : 2025/6/3 14:05
 * @description: 包断激励视频广告
 */
class BiddingBuyOutBuyOutVideoActivity : AbsBiddingActivity() {

    private var isCanClickClose = false
    private var binding: ActivityBiddingBuyOutVideoUnspecifiedLayoutBinding? = null // 页面数据


    // =============================================================================================


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        binding?.clRoot?.let {
            it.post {
                it.setPadding(
                    it.paddingLeft,
                    ImmersionBar.getStatusBarHeight(this),
                    it.paddingRight,
                    it.paddingBottom
                )
            }
        }
    }

    override fun getAdType(): Int = MbAdType.MB_AD_TYPE_VIDEO

    override fun getLogTag(): String = AdLogger.TAG_AD_VIDEO

    override fun getSubContentView(): View? {
        binding = ActivityBiddingBuyOutVideoUnspecifiedLayoutBinding.inflate(layoutInflater)
        return binding?.root
    }

    override fun getMediaContain(): FrameLayout? = binding?.container

    override fun getVolumeContainer(): FrameLayout? = binding?.flVolumeContainer

    override fun getCountDownTimes(): Int = SceneGlobalConfig.getVideoCd()

    override fun showAdInformation() {
        // 广告主信息 展示
        setAdvertiserInformation()
        // 广告点击事件
        ViewUtil.multipleClickListener(
            findViewById<FrameLayout>(R.id.clAdEndLayout)
        ) {
            adClick()
        }

        // 关闭按钮
        binding?.ivClose?.setOnClickListener {
            if (isCanClickClose.not()) {
                // 只有在最后10秒的时候才能点击
                onLog(
                    level = Log.DEBUG,
                    msg = "showAdInformation() --> setOnClickListener() --> 只有在最后10秒的时候才能点击"
                )
                return@setOnClickListener
            }
            showCloseAdDialog()
            //finishAdActivity()
        }
        binding?.ivAdClose?.setOnClickListener {
            finishAdActivity()
        }
    }

    @SuppressLint("StringFormatMatches")
    override fun refreshCountDownView(i: Int) {
        if (i <= 10) {
            isCanClickClose = true
            binding?.ivClose?.setImageResource(R.mipmap.ad_video_01)
        } else {
            binding?.ivClose?.setImageResource(R.mipmap.ad_video_03)
        }

        if (i == getCountDownTimes()) {
            binding?.llMember?.visibility = View.VISIBLE
        }
        // 倒计时开始了
        //val str = "Reward in ${i}s"
        val str = "${i}s"
        binding?.tvCd?.text = str
        // i= 1 的时候，skip 可点击
        if (i == 0) {
            binding?.llMember?.visibility = View.GONE
            //ivVolume?.visibility = View.GONE
            adRewarded()
        }
    }

    override fun onAdCompletion() {
        binding?.clAdEndLayout?.visibility = View.VISIBLE
    }

    override fun showCloseAdDialog() {
        if (isCanClickClose.not()) {
            // 只有在最后10秒的时候才能点击
            onLog(
                level = Log.DEBUG, msg = "showCloseAdDialog() --> 只有在最后10秒的时候才能展示"
            )
            return
        }

        setShowCloseAdDialog(isShow = true)
        BiddingCloseAdDialog().setCallback(closeAdCallback = {
            finishAdActivity()
        }, resumeAdCallback = {
            setShowCloseAdDialog(isShow = false)
        }).showDialog(this, "CloseAdDialog")
    }

    override fun getAdIcon(): View? = findViewById<AdTagView>(R.id.adIcon)


    // ======================================== 广告展示 =============================================


    private fun setAdvertiserInformation() {
        kotlin.runCatching {
            binding?.tvAvatar?.let {
                if (TextUtils.isEmpty(getAdPlan()?.advertiserAvatarPath)) {
                    Glide.with(this).load(getAdPlan()?.advertiserAvatar).into(it)
                } else {
                    Glide.with(this).load(getAdPlan()?.advertiserAvatarPath).into(it)
                }
            }
            binding?.tvTitle?.text = getAdMaterialList()?.title
            binding?.tvDesc?.text = getAdMaterialList()?.desc
            binding?.tvBtn?.text = getAdMaterialList()?.buttonText
        }

        kotlin.runCatching {
            binding?.tvAdAvatar?.let {
                if (TextUtils.isEmpty(getAdPlan()?.advertiserAvatarPath)) {
                    Glide.with(this).load(getAdPlan()?.advertiserAvatar).into(it)
                } else {
                    Glide.with(this).load(getAdPlan()?.advertiserAvatarPath).into(it)
                }
            }

            binding?.tvAdTitle?.text = getAdMaterialList()?.title
            binding?.tvAdDesc?.text = getAdMaterialList()?.desc
            binding?.tvAdBtn?.text = getAdMaterialList()?.buttonText
        }
    }

}
